@@ -14,7 +14,7 @@ import aws_cdk.aws_dynamodb
 import aws_cdk.aws_iam
 import aws_cdk.aws_lambda
 import aws_cdk.core
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-dynamodb-global", "0.38.0", __name__, "aws-dynamodb-global@0.38.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-dynamodb-global", "1.10.1", __name__, "aws-dynamodb-global@1.10.1.jsii.tgz")
 class GlobalTable(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-dynamodb-global.GlobalTable"):
     """This class works by deploying an AWS DynamoDB table into each region specified in  GlobalTableProps.regions[], then triggering a CloudFormation Custom Resource Lambda to link them all together to create linked AWS Global DynamoDB tables.
 
@@ -38,7 +38,7 @@ class GlobalTable(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@a
         :param removal_policy: The removal policy to apply to the DynamoDB Table. Default: RemovalPolicy.RETAIN
         :param server_side_encryption: Whether server-side encryption with an AWS managed customer master key is enabled. Default: - server-side encryption is enabled with an AWS owned customer master key
         :param sort_key: Table sort key attribute definition. Default: no sort key
-        :param stream: When an item in the table is modified, StreamViewType determines what information is written to the stream for this table. Valid values for StreamViewType are: Default: undefined, streams are disabled
+        :param stream: When an item in the table is modified, StreamViewType determines what information is written to the stream for this table. Default: undefined, streams are disabled
         :param time_to_live_attribute: The name of TTL attribute. Default: - TTL is disabled
         :param write_capacity: The write capacity for the table. Careful if you add Global Secondary Indexes, as those will share the table's provisioned throughput. Can only be provided if billingMode is Provisioned. Default: 5
 
@@ -75,7 +75,7 @@ class GlobalTableProps(aws_cdk.core.StackProps, aws_cdk.aws_dynamodb.TableOption
         :param removal_policy: The removal policy to apply to the DynamoDB Table. Default: RemovalPolicy.RETAIN
         :param server_side_encryption: Whether server-side encryption with an AWS managed customer master key is enabled. Default: - server-side encryption is enabled with an AWS owned customer master key
         :param sort_key: Table sort key attribute definition. Default: no sort key
-        :param stream: When an item in the table is modified, StreamViewType determines what information is written to the stream for this table. Valid values for StreamViewType are: Default: undefined, streams are disabled
+        :param stream: When an item in the table is modified, StreamViewType determines what information is written to the stream for this table. Default: undefined, streams are disabled
         :param time_to_live_attribute: The name of TTL attribute. Default: - TTL is disabled
         :param write_capacity: The write capacity for the table. Careful if you add Global Secondary Indexes, as those will share the table's provisioned throughput. Can only be provided if billingMode is Provisioned. Default: 5
         :param regions: Array of environments to create DynamoDB tables in. The tables will all be created in the same account.
@@ -200,8 +200,6 @@ class GlobalTableProps(aws_cdk.core.StackProps, aws_cdk.aws_dynamodb.TableOption
     def stream(self) -> typing.Optional[aws_cdk.aws_dynamodb.StreamViewType]:
         """When an item in the table is modified, StreamViewType determines what information is written to the stream for this table.
 
-        Valid values for StreamViewType are:
-
         default
         :default: undefined, streams are disabled
         """
